@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.33.2.1 2002/11/23 13:45:29 joern Exp $
+# $Id: Project.pm,v 1.33.2.2 2002/12/02 18:22:00 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -127,7 +127,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.33.2.1 2002/11/23 13:45:29 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.33.2.2 2002/12/02 18:22:00 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -228,6 +228,24 @@ sub load {
 	1;
 }
 
+sub get_free_diskspace {
+	my $self = shift;
+	my %par = @_;
+	my ($kb) = @par{'kb'};
+
+	my $dir  = $self->avi_dir;
+	
+	if ( not -d $dir ) {
+		mkpath ( [$dir], 0, 0755);
+	}
+	
+	my $df   = qx[ df -Pk $dir ];
+	my ($free) = $df =~ /\s+\d+\s+\d+\s+(\d+)/;
+	$free = int ($free/1024) if not $kb;
+
+	return $free;
+}
+
 sub rip_data_source {
 	my $self = shift; $self->trace_in;
 	
